@@ -1,27 +1,36 @@
 """Module containing entity classes."""
 
-from typing import Dict
+from typing import Dict, List
+from .custom_code import CustomCode
 
 
 class Entity:
     """Class that serves as a version configuration for a logical subset of a Pipeline."""
 
     def __init__(
-        self, name: str, version: str, stage_config: Dict[str, Dict[str, str]] = None,
+        self,
+        name: str,
+        version: str,
+        stage_config: Dict[str, Dict[str, str]] = None,
+        custom_operators: Dict[str, List[CustomCode]] = None,
     ):
         """
         Create an Entity object.
 
         :param name: the name of the entity
-        :param version: the version of the entity, this can be used for table naming
-        this entity belongs to.
+        :param version: the version of the entity, this can be used for table naming this entity belongs to.
         :param stage_config: a dictionary with the name of the stage as key and a dictionary of query names
         and their versions as value.
+        :param custom_operators: a dictionary with the name of the stage as key and a list
+                                 of CustomCode objects allowing to inject custom Airflow operator
+                                 into the pipeline as value
+        :type custom_operators: list
         """
         self.name = name
         self.version = version
         self.stage_config = stage_config
         self.transformations = {}
+        self.custom_operators = custom_operators or {}
 
     @classmethod
     def from_dict(cls, d: dict):
@@ -228,7 +237,11 @@ class ParametrizedEntity:
     """Class that serves as a version configuration for a logical subset of a ParametrizedPipeline."""
 
     def __init__(
-        self, name: str, version: str, stage_config: Dict[str, Dict[str, str]] = None
+        self,
+        name: str,
+        version: str,
+        stage_config: Dict[str, Dict[str, str]] = None,
+        custom_operators: Dict[str, List[CustomCode]] = None,
     ):
         """
         Create a ParametrizedEntity object.
@@ -246,6 +259,7 @@ class ParametrizedEntity:
         self.version = version
         self.stage_config = stage_config
         self.transformations = {}
+        self.custom_operators = custom_operators or {}
 
     @classmethod
     def from_dict(cls, d: dict):
